@@ -418,6 +418,19 @@ def test_kdf_str_salt():
         )
 
 
+def test_kdf_no_warn_rounds():
+    bcrypt.kdf(
+        b"password", b"salt", 10, 10, True
+    )
+
+
+def test_kdf_warn_rounds():
+    with pytest.warns(UserWarning):
+        bcrypt.kdf(
+            b"password", b"salt", 10, 10
+        )
+
+
 @pytest.mark.parametrize(
     ("password", "salt", "desired_key_bytes", "rounds", "error"),
     [
